@@ -10,7 +10,10 @@ use AutoLoader;
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
+    libusb_has_capability
     libusb_error_name
+    libusb_get_version
+    libusb_setlocale
     libusb_strerror
 
 	LIBUSBX_API_VERSION
@@ -156,7 +159,7 @@ our @EXPORT = qw(
 	LIBUSB_TRANSFER_TYPE_MASK
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -377,21 +380,7 @@ Implementation status: complete.
 
 =head2 USB descriptors
 
-Implementation status: The following descriptor types are not yet implemented.
-
-=over
-
-=item * SuperSpeed endpoint companion descriptor
-
-=item * Binary Object Store (BOS) descriptor
-
-=item * USB 2.0 Extension descriptor
-
-=item * SuperSpeed USB Device Capability descriptor
-
-=item * Container ID descriptor
-
-=back
+Implementation status: complete.
 
 All descriptors are returned as hash references.
 
